@@ -5,9 +5,9 @@ our $VERSION = $Gtk2::Ex::DbLinker::VERSION;
 use strict;
 use warnings;
 use Glib qw/TRUE FALSE/;
-use Carp;
+use Carp qw(croak confess carp);
 use DateTime::Format::Strptime;
-
+use Data::Dumper;
 my %fieldtype = (
 varchar => "Glib::String" ,
 char =>"Glib::String" ,
@@ -149,6 +149,40 @@ sub add_childform {
 
 }
 
+#add the values contained in the array @$aref in the combo $name
+#the combo has to be a Gtk2::ComboBox
+
+sub add_combo_values {
+	my ($self, $w, $aref)=@_;
+		my $wref = ref $w;
+	my @supp_class = (qw/Gtk2::ComboBox Gtk2::ComboBoxEntry/);
+	my %supported = map {$_ => 1} @supp_class;
+	confess ("only ". join(" ", @supp_class)  . " supported by add_combo_values") unless ($supported{$wref});
+	if ($wref eq "Gtk2::ComboBox"){
+		my $renderer = Gtk2::CellRendererText->new();
+		$w->pack_start($renderer, 'TRUE');
+		$w->add_attribute($renderer,'text',0);
+	}
+	my $size=0;
+	my @model;
+	if (defined $aref->[0]){$size = scalar (@{$aref->[0]});} else {$aref=[];}
+	for (my $col_i=0; $col_i<$size; $col_i++){
+		push @model, "Glib::String"
+	}
+	 my $lst = Gtk2::ListStore->new(@model);
+	my $i_pos=0;
+	@model = ();
+	 foreach my $row ( @$aref ) {
+	        push @model, $lst->append; 
+		 for (my $col_i=0; $col_i<$size; $col_i++){push @model, $col_i, $row->[$col_i]; }
+		 $lst->set(@model);
+		 @model=();
+	 
+	 }
+	$w->set_model($lst);
+	if ($wref eq "Gtk2::ComboBoxEntry") {$w->set_text_column(0)};
+}
+
 
 #dman must contains all the rows 
 sub add_combo{
@@ -1106,6 +1140,11 @@ C<auto_apply> defaults to 1, meaning that apply will be called if a changed has
 
 =back
 
+=head2 C<add_combo_values( $widget, $array_ref); >
+
+Populates a Gtk2::ComboBox or Gtk2::ComboBoxEntry widget with a static list of values. 
+The array whose reference is stored in $array_ref is a list of array that described the rows: [[return value1, displayed value1], [...], ...]
+
 =head2 C<add_combo( {	data_manager =E<gt> $dman, 	id =E<gt> 'noed',  fields =E<gt> ["id", "nom"], }); >
 
 Once the constructor has been called, combo designed in the glade file received their rows with this method. 
